searchData={"items":[{"type":"module","title":"Gitly","doc":"A module for downloading and extracting Git repositories.\n\nThis module provides functionality to download repositories from various Git hosting services,\nextract them, and manage the process with various options for caching, retrying, and formatting.","ref":"Gitly.html"},{"type":"function","title":"Gitly.download/2","doc":"Downloads a repository and returns the path to the archive.","ref":"Gitly.html#download/2"},{"type":"function","title":"Parameters - Gitly.download/2","doc":"* `repository` - The repository identifier (e.g., \"username/repo\").\n  * `opts` - A keyword list of options (see \"Options\" section in `gitly/2`).","ref":"Gitly.html#download/2-parameters"},{"type":"function","title":"Returns - Gitly.download/2","doc":"* `{:ok, path}` where `path` is the location of the downloaded archive.\n  * `{:error, reason}` if the download fails.","ref":"Gitly.html#download/2-returns"},{"type":"function","title":"Examples - Gitly.download/2","doc":"iex> Gitly.download(\"iwatakeshi/gitly\")\n    {:ok, \"/path/to/downloaded/archive.zip\"}","ref":"Gitly.html#download/2-examples"},{"type":"function","title":"Gitly.extract/2","doc":"Extracts an archive to a given destination.","ref":"Gitly.html#extract/2"},{"type":"function","title":"Parameters - Gitly.extract/2","doc":"* `path` - The path to the archive file.\n  * `opts` - A keyword list of options (see \"Options\" section in `gitly/2`).","ref":"Gitly.html#extract/2-parameters"},{"type":"function","title":"Returns - Gitly.extract/2","doc":"* `{:ok, path}` where `path` is the location of the extracted contents.\n  * `{:error, reason}` if the extraction fails.","ref":"Gitly.html#extract/2-returns"},{"type":"function","title":"Examples - Gitly.extract/2","doc":"iex> Gitly.extract(\"/path/to/archive.zip\")\n    {:ok, \"/path/to/extracted/contents\"}","ref":"Gitly.html#extract/2-examples"},{"type":"function","title":"Gitly.extract/3","doc":"Extracts an archive to a specified destination.","ref":"Gitly.html#extract/3"},{"type":"function","title":"Parameters - Gitly.extract/3","doc":"* `path` - The path to the archive file.\n  * `dest` - The destination path for extraction.\n  * `opts` - A keyword list of options (see \"Options\" section in `gitly/2`).","ref":"Gitly.html#extract/3-parameters"},{"type":"function","title":"Returns - Gitly.extract/3","doc":"* `{:ok, path}` where `path` is the location of the extracted contents.\n  * `{:error, reason}` if the extraction fails.","ref":"Gitly.html#extract/3-returns"},{"type":"function","title":"Examples - Gitly.extract/3","doc":"iex> Gitly.extract(\"/path/to/archive.zip\", \"/path/to/destination\")\n    {:ok, \"/path/to/destination\"}","ref":"Gitly.html#extract/3-examples"},{"type":"function","title":"Gitly.gitly/2","doc":"Downloads a repository and returns the path to the extracted archive.","ref":"Gitly.html#gitly/2"},{"type":"function","title":"Parameters - Gitly.gitly/2","doc":"* `repository` - The repository identifier (e.g., \"username/repo\").\n  * `opts` - A keyword list of options (see \"Options\" section).","ref":"Gitly.html#gitly/2-parameters"},{"type":"function","title":"Options - Gitly.gitly/2","doc":"* `:force` - If true, force the download of the archive.\n  * `:cache` - If true, use the local cache to download the archive.\n  * `:overwrite` - If true, overwrite existing files when extracting the archive.\n  * `:retry` - Retry options for Req. See https://hexdocs.pm/req/Req.Steps.html#retry/1-request-options\n  * `:retry_delay` - Function to determine delay between retries. Default is exponential backoff.\n  * `:retry_log_level` - The log level for retry logs. Set to false to disable logging.\n  * `:max_retries` - The maximum number of retries before giving up.\n  * `:ref` - The ref to download from the repository.\n  * `:root` - The root path to store the archive.\n  * `:format` - The format of the archive (:zip, :tar, :tar_gz, or :tgz).","ref":"Gitly.html#gitly/2-options"},{"type":"function","title":"Returns - Gitly.gitly/2","doc":"* `{:ok, path}` where `path` is the location of the extracted repository.\n  * `{:error, reason}` if the operation fails.","ref":"Gitly.html#gitly/2-returns"},{"type":"function","title":"Examples - Gitly.gitly/2","doc":"iex> Gitly.gitly(\"iwatakeshi/gitly\")\n    {:ok, \"/path/to/extracted/repo\"}","ref":"Gitly.html#gitly/2-examples"},{"type":"type","title":"Gitly.opts/0","doc":"","ref":"Gitly.html#t:opts/0"},{"type":"type","title":"Gitly.retry_delay_fun/0","doc":"","ref":"Gitly.html#t:retry_delay_fun/0"},{"type":"type","title":"Gitly.retry_fun/0","doc":"","ref":"Gitly.html#t:retry_fun/0"},{"type":"module","title":"Gitly.Parser","doc":"A module to parse repository URLs and return metadata.\n\nThis module can handle various formats of repository URLs and convert them\ninto a standardized metadata map.","ref":"Gitly.Parser.html"},{"type":"function","title":"Gitly.Parser.parse/1","doc":"Parses a binary string and returns a metadata map.\n\nThe following strings are valid:\n* owner/repo\n* https://host.com/owner/repo\n* https://host.com/owner/repo.git\n* host.com/owner/repo\n* host:owner/repo","ref":"Gitly.Parser.html#parse/1"},{"type":"function","title":"Parameters - Gitly.Parser.parse/1","doc":"* `str` - A binary string representing the repository URL.","ref":"Gitly.Parser.html#parse/1-parameters"},{"type":"function","title":"Returns - Gitly.Parser.parse/1","doc":"* `{:ok, map}` where the map contains:\n  * `:host` - the host of the repository\n  * `:owner` - the owner of the repository\n  * `:repo` - the repository name\n  * `:ref` - the reference (default is \"main\")\n* `{:error, reason}` if the parsing fails.","ref":"Gitly.Parser.html#parse/1-returns"},{"type":"function","title":"Examples - Gitly.Parser.parse/1","doc":"iex> Gitly.Parser.parse(\"iwatakeshi/gitly\")\n    {:ok, %{host: \"github.com\", owner: \"iwatakeshi\", repo: \"gitly\", ref: \"main\"}}\n\n    iex> Gitly.Parser.parse(\"https://github.com/iwatakeshi/gitly\")\n    {:ok, %{host: \"github.com\", owner: \"iwatakeshi\", repo: \"gitly\", ref: \"main\"}}\n\n    iex> Gitly.Parser.parse(\"github.com/iwatakeshi/gitly\")\n    {:ok, %{host: \"github.com\", owner: \"iwatakeshi\", repo: \"gitly\", ref: \"main\"}}\n\n    iex> Gitly.Parser.parse(\"github:iwatakeshi/gitly\")\n    {:ok, %{host: \"github.com\", owner: \"iwatakeshi\", repo: \"gitly\", ref: \"main\"}}\n\n    iex> Gitly.Parser.parse(\"blah\")\n    {:error, \"Invalid URL\"}","ref":"Gitly.Parser.html#parse/1-examples"},{"type":"function","title":"Gitly.Parser.parse/2","doc":"Parses a binary string with additional options and returns a metadata map.\n\nThis function is similar to `parse/1` but allows specifying additional options.","ref":"Gitly.Parser.html#parse/2"},{"type":"function","title":"Parameters - Gitly.Parser.parse/2","doc":"* `str` - A binary string representing the repository URL.\n* `opts` - A map of options:\n  * `:host` - the host of the repository (default is \"github.com\")\n  * `:ref` - the ref of the repository (default is \"main\")","ref":"Gitly.Parser.html#parse/2-parameters"},{"type":"function","title":"Returns - Gitly.Parser.parse/2","doc":"* `{:ok, map}` where the map contains the parsed metadata.\n* `{:error, reason}` if the parsing fails.","ref":"Gitly.Parser.html#parse/2-returns"},{"type":"function","title":"Examples - Gitly.Parser.parse/2","doc":"iex> Gitly.Parser.parse(\"iwatakeshi/gitly\", %{host: \"gitlab.com\", ref: \"develop\"})\n    {:ok, %{host: \"gitlab.com\", owner: \"iwatakeshi\", repo: \"gitly\", ref: \"develop\"}}","ref":"Gitly.Parser.html#parse/2-examples"},{"type":"module","title":"Gitly.Task","doc":"A struct to represent a task.","ref":"Gitly.Task.html"},{"type":"function","title":"Gitly.Task.error?/1","doc":"","ref":"Gitly.Task.html#error?/1"},{"type":"function","title":"Gitly.Task.from_list/1","doc":"","ref":"Gitly.Task.html#from_list/1"},{"type":"function","title":"Gitly.Task.new/2","doc":"","ref":"Gitly.Task.html#new/2"},{"type":"function","title":"Gitly.Task.run/2","doc":"","ref":"Gitly.Task.html#run/2"},{"type":"function","title":"Gitly.Task.run_all_tasks/1","doc":"Run all tasks asynchronously.","ref":"Gitly.Task.html#run_all_tasks/1"},{"type":"function","title":"Gitly.Task.run_until_error/2","doc":"Run all tasks but stop when an error occurs.","ref":"Gitly.Task.html#run_until_error/2"},{"type":"function","title":"Gitly.Task.run_until_success/2","doc":"Run tasks one by one and stop when a task succeeds.","ref":"Gitly.Task.html#run_until_success/2"},{"type":"function","title":"Gitly.Task.success?/1","doc":"","ref":"Gitly.Task.html#success?/1"},{"type":"function","title":"Gitly.Task.update_error/2","doc":"","ref":"Gitly.Task.html#update_error/2"},{"type":"function","title":"Gitly.Task.update_result/2","doc":"","ref":"Gitly.Task.html#update_result/2"},{"type":"module","title":"Gitly.Task.Builder","doc":"A module to build a task order.","ref":"Gitly.Task.Builder.html"},{"type":"function","title":"Gitly.Task.Builder.build_task_order/1","doc":"Builds a task order based on the given options.","ref":"Gitly.Task.Builder.html#build_task_order/1"},{"type":"type","title":"Gitly.Task.Builder.build_task_order_opts/0","doc":"","ref":"Gitly.Task.Builder.html#t:build_task_order_opts/0"},{"type":"module","title":"Gitly.Utils.Archive","doc":"A module to handle archive operations.\n\nThis module provides functionality for building archive URLs, creating archive paths,\ndownloading archives, and extracting them.","ref":"Gitly.Utils.Archive.html"},{"type":"function","title":"Gitly.Utils.Archive.build_archive_url/2","doc":"Builds an archive URL based on the given input.","ref":"Gitly.Utils.Archive.html#build_archive_url/2"},{"type":"function","title":"Parameters - Gitly.Utils.Archive.build_archive_url/2","doc":"* `input` - A map containing archive information (must include `:host`).\n  * `format` - The desired archive format (default: `:tar_gz`).","ref":"Gitly.Utils.Archive.html#build_archive_url/2-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Archive.build_archive_url/2","doc":"* A string containing the built URL, or `{:error, reason}` if the operation fails.","ref":"Gitly.Utils.Archive.html#build_archive_url/2-returns"},{"type":"function","title":"Examples - Gitly.Utils.Archive.build_archive_url/2","doc":"iex> input = %{host: \"github.com\", owner: \"elixir-lang\", repo: \"elixir\", ref: \"main\"}\n    iex> Gitly.Utils.Archive.build_archive_url(input)\n    \"https://github.com/elixir-lang/elixir/archive/main.tar.gz\"","ref":"Gitly.Utils.Archive.html#build_archive_url/2-examples"},{"type":"function","title":"Gitly.Utils.Archive.create_archive_path/2","doc":"Creates an archive path based on the given input.","ref":"Gitly.Utils.Archive.html#create_archive_path/2"},{"type":"function","title":"Parameters - Gitly.Utils.Archive.create_archive_path/2","doc":"* `input` - A map containing archive information (must include `:host`, `:owner`, `:repo`, and `:ref`).\n  * `opts` - A keyword list of options:\n    * `:root` - The root path (default: result of `FS.root_path()`).\n    * `:format` - The archive format (default: `:tar_gz`).","ref":"Gitly.Utils.Archive.html#create_archive_path/2-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Archive.create_archive_path/2","doc":"* A string containing the created archive path.","ref":"Gitly.Utils.Archive.html#create_archive_path/2-returns"},{"type":"function","title":"Examples - Gitly.Utils.Archive.create_archive_path/2","doc":"iex> input = %{host: \"github.com\", owner: \"elixir-lang\", repo: \"elixir\", ref: \"main\"}\n    iex> Gitly.Utils.Archive.create_archive_path(input, root: \"/tmp\")\n    \"/tmp/github/elixir-lang/elixir/main.tar.gz\"","ref":"Gitly.Utils.Archive.html#create_archive_path/2-examples"},{"type":"function","title":"Gitly.Utils.Archive.download/3","doc":"Downloads an archive from the given URL and saves it to the given path.","ref":"Gitly.Utils.Archive.html#download/3"},{"type":"function","title":"Parameters - Gitly.Utils.Archive.download/3","doc":"* `url` - The URL of the archive to download.\n  * `path` - The local path where the archive should be saved.\n  * `opts` - A keyword list of options:\n    * `:retry` - The retry strategy (default: `:transient`).","ref":"Gitly.Utils.Archive.html#download/3-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Archive.download/3","doc":"* `{:ok, path}` if the download was successful.\n  * `{:error, reason}` if the download failed.","ref":"Gitly.Utils.Archive.html#download/3-returns"},{"type":"function","title":"Examples - Gitly.Utils.Archive.download/3","doc":"iex> Gitly.Utils.Archive.download(\"https://example.com/archive.zip\", \"/tmp/archive.zip\")\n    {:ok, \"/tmp/archive.zip\"}","ref":"Gitly.Utils.Archive.html#download/3-examples"},{"type":"function","title":"Gitly.Utils.Archive.extract/3","doc":"Extracts an archive from the given file path to the given destination.","ref":"Gitly.Utils.Archive.html#extract/3"},{"type":"function","title":"Parameters - Gitly.Utils.Archive.extract/3","doc":"* `file_path` - The path to the archive file.\n  * `dest` - The destination directory where the archive should be extracted.\n  * `opts` - A keyword list of options:\n    * `:force` - Whether to force extraction even if the destination exists (default: `false`).\n    * `:overwrite` - Whether to overwrite existing files (default: `false`).","ref":"Gitly.Utils.Archive.html#extract/3-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Archive.extract/3","doc":"* `{:ok, dest}` if the extraction was successful.\n  * `{:error, reason}` if the extraction failed.","ref":"Gitly.Utils.Archive.html#extract/3-returns"},{"type":"function","title":"Examples - Gitly.Utils.Archive.extract/3","doc":"iex> Gitly.Utils.Archive.extract(\"/tmp/archive.zip\", \"/tmp/extracted\")\n    {:ok, \"/tmp/extracted\"}","ref":"Gitly.Utils.Archive.html#extract/3-examples"},{"type":"module","title":"Gitly.Utils.Archive.Extractor","doc":"Provides functionality to extract various types of archives.\n\nThis module supports extracting ZIP, TAR, TAR.GZ, and TGZ archives.","ref":"Gitly.Utils.Archive.Extractor.html"},{"type":"function","title":"Gitly.Utils.Archive.Extractor.extract/2","doc":"Extracts an archive to the given destination.","ref":"Gitly.Utils.Archive.Extractor.html#extract/2"},{"type":"function","title":"Parameters - Gitly.Utils.Archive.Extractor.extract/2","doc":"* `path` - The path to the archive file.\n  * `dest` - The destination directory where the archive should be extracted.","ref":"Gitly.Utils.Archive.Extractor.html#extract/2-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Archive.Extractor.extract/2","doc":"* `{:ok, dest}` if the extraction was successful.\n  * `{:error, reason}` if the extraction failed or the archive type is unsupported.","ref":"Gitly.Utils.Archive.Extractor.html#extract/2-returns"},{"type":"function","title":"Examples - Gitly.Utils.Archive.Extractor.extract/2","doc":"iex> Gitly.Utils.Archive.Extractor.extract(\"example.zip\", \"/tmp/extract\")\n    {:ok, \"/tmp/extract\"}\n\n    iex> Gitly.Utils.Archive.Extractor.extract(\"example.rar\", \"/tmp/extract\")\n    {:error, \"Unsupported archive type\"}","ref":"Gitly.Utils.Archive.Extractor.html#extract/2-examples"},{"type":"type","title":"Gitly.Utils.Archive.Extractor.extract_result/0","doc":"","ref":"Gitly.Utils.Archive.Extractor.html#t:extract_result/0"},{"type":"module","title":"Gitly.Utils.Archive.Type","doc":"A module to handle archive types.\n\nThis module provides functions to work with various archive formats,\nincluding zip, tar, tar.gz, tgz, tar.bz2, and tar.xz.","ref":"Gitly.Utils.Archive.Type.html"},{"type":"function","title":"Gitly.Utils.Archive.Type.ensure_leading_dot/1","doc":"Ensures the given extension has a leading dot.","ref":"Gitly.Utils.Archive.Type.html#ensure_leading_dot/1"},{"type":"function","title":"Parameters - Gitly.Utils.Archive.Type.ensure_leading_dot/1","doc":"* `ext` - The extension string.","ref":"Gitly.Utils.Archive.Type.html#ensure_leading_dot/1-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Archive.Type.ensure_leading_dot/1","doc":"* The extension string with a leading dot.","ref":"Gitly.Utils.Archive.Type.html#ensure_leading_dot/1-returns"},{"type":"function","title":"Examples - Gitly.Utils.Archive.Type.ensure_leading_dot/1","doc":"iex> Gitly.Utils.Archive.Type.ensure_leading_dot(\"zip\")\n    \".zip\"\n\n    iex> Gitly.Utils.Archive.Type.ensure_leading_dot(\".tar.gz\")\n    \".tar.gz\"","ref":"Gitly.Utils.Archive.Type.html#ensure_leading_dot/1-examples"},{"type":"function","title":"Gitly.Utils.Archive.Type.from_path/1","doc":"Returns the archive type as an atom from the given path.","ref":"Gitly.Utils.Archive.Type.html#from_path/1"},{"type":"function","title":"Parameters - Gitly.Utils.Archive.Type.from_path/1","doc":"* `path` - The file path to check.","ref":"Gitly.Utils.Archive.Type.html#from_path/1-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Archive.Type.from_path/1","doc":"* The archive type as an atom (`:zip`, `:tar`, etc.) or `:unknown` if not recognized.","ref":"Gitly.Utils.Archive.Type.html#from_path/1-returns"},{"type":"function","title":"Examples - Gitly.Utils.Archive.Type.from_path/1","doc":"iex> Gitly.Utils.Archive.Type.from_path(\"example.tar.gz\")\n    :tar_gz\n\n    iex> Gitly.Utils.Archive.Type.from_path(\"example.txt\")\n    :unknown","ref":"Gitly.Utils.Archive.Type.html#from_path/1-examples"},{"type":"function","title":"Gitly.Utils.Archive.Type.from_string/2","doc":"Returns the archive type as an atom from the given string.","ref":"Gitly.Utils.Archive.Type.html#from_string/2"},{"type":"function","title":"Parameters - Gitly.Utils.Archive.Type.from_string/2","doc":"* `string` - The string representing the archive extension.\n  * `dot` - Whether the string includes a leading dot (default: true).","ref":"Gitly.Utils.Archive.Type.html#from_string/2-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Archive.Type.from_string/2","doc":"* The archive type as an atom (`:zip`, `:tar`, etc.) or `:unknown` if not recognized.","ref":"Gitly.Utils.Archive.Type.html#from_string/2-returns"},{"type":"function","title":"Examples - Gitly.Utils.Archive.Type.from_string/2","doc":"iex> Gitly.Utils.Archive.Type.from_string(\".zip\")\n    :zip\n\n    iex> Gitly.Utils.Archive.Type.from_string(\"tar.gz\", false)\n    :tar_gz\n\n    iex> Gitly.Utils.Archive.Type.from_string(\"rar\")\n    :unknown","ref":"Gitly.Utils.Archive.Type.html#from_string/2-examples"},{"type":"function","title":"Gitly.Utils.Archive.Type.from_type/2","doc":"Returns the archive type as a string from the given type.","ref":"Gitly.Utils.Archive.Type.html#from_type/2"},{"type":"function","title":"Parameters - Gitly.Utils.Archive.Type.from_type/2","doc":"* `type` - The archive type as an atom.\n  * `dot` - Whether to include a leading dot in the result (default: true).","ref":"Gitly.Utils.Archive.Type.html#from_type/2-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Archive.Type.from_type/2","doc":"* The archive extension as a string or `:unknown` if not recognized.","ref":"Gitly.Utils.Archive.Type.html#from_type/2-returns"},{"type":"function","title":"Examples - Gitly.Utils.Archive.Type.from_type/2","doc":"iex> Gitly.Utils.Archive.Type.from_type(:zip)\n    \".zip\"\n\n    iex> Gitly.Utils.Archive.Type.from_type(:tar_gz, false)\n    \"tar.gz\"\n\n    iex> Gitly.Utils.Archive.Type.from_type(:unknown)\n    :unknown","ref":"Gitly.Utils.Archive.Type.html#from_type/2-examples"},{"type":"function","title":"Gitly.Utils.Archive.Type.trim_extension/1","doc":"Removes the archive extension from the given path.","ref":"Gitly.Utils.Archive.Type.html#trim_extension/1"},{"type":"function","title":"Parameters - Gitly.Utils.Archive.Type.trim_extension/1","doc":"* `path` - The file path.","ref":"Gitly.Utils.Archive.Type.html#trim_extension/1-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Archive.Type.trim_extension/1","doc":"* The path without the archive extension.","ref":"Gitly.Utils.Archive.Type.html#trim_extension/1-returns"},{"type":"function","title":"Examples - Gitly.Utils.Archive.Type.trim_extension/1","doc":"iex> Gitly.Utils.Archive.Type.trim_extension(\"example.tar.gz\")\n    \"example\"\n\n    iex> Gitly.Utils.Archive.Type.trim_extension(\"example.txt\")\n    \"example.txt\"","ref":"Gitly.Utils.Archive.Type.html#trim_extension/1-examples"},{"type":"function","title":"Gitly.Utils.Archive.Type.trim_leading_dot/1","doc":"Removes the leading dot from the given extension.","ref":"Gitly.Utils.Archive.Type.html#trim_leading_dot/1"},{"type":"function","title":"Parameters - Gitly.Utils.Archive.Type.trim_leading_dot/1","doc":"* `ext` - The extension string.","ref":"Gitly.Utils.Archive.Type.html#trim_leading_dot/1-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Archive.Type.trim_leading_dot/1","doc":"* The extension string without a leading dot.","ref":"Gitly.Utils.Archive.Type.html#trim_leading_dot/1-returns"},{"type":"function","title":"Examples - Gitly.Utils.Archive.Type.trim_leading_dot/1","doc":"iex> Gitly.Utils.Archive.Type.trim_leading_dot(\".zip\")\n    \"zip\"\n\n    iex> Gitly.Utils.Archive.Type.trim_leading_dot(\"tar.gz\")\n    \"tar.gz\"","ref":"Gitly.Utils.Archive.Type.html#trim_leading_dot/1-examples"},{"type":"function","title":"Gitly.Utils.Archive.Type.valid?/1","doc":"Checks if the given path is a valid archive.","ref":"Gitly.Utils.Archive.Type.html#valid?/1"},{"type":"function","title":"Parameters - Gitly.Utils.Archive.Type.valid?/1","doc":"* `path` - The file path to check.","ref":"Gitly.Utils.Archive.Type.html#valid?/1-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Archive.Type.valid?/1","doc":"* `true` if the path ends with a valid archive extension, `false` otherwise.","ref":"Gitly.Utils.Archive.Type.html#valid?/1-returns"},{"type":"function","title":"Examples - Gitly.Utils.Archive.Type.valid?/1","doc":"iex> Gitly.Utils.Archive.Type.valid?(\"example.zip\")\n    true\n\n    iex> Gitly.Utils.Archive.Type.valid?(\"example.txt\")\n    false","ref":"Gitly.Utils.Archive.Type.html#valid?/1-examples"},{"type":"type","title":"Gitly.Utils.Archive.Type.ext/0","doc":"","ref":"Gitly.Utils.Archive.Type.html#t:ext/0"},{"type":"module","title":"Gitly.Utils.FS","doc":"A module for file system operations.\n\nThis module provides utility functions for common file system operations\nsuch as ensuring directories exist, moving files, and removing directories.","ref":"Gitly.Utils.FS.html"},{"type":"function","title":"Gitly.Utils.FS.ensure_dir_exists/1","doc":"Ensures that the directory for the given path exists.\n\nCreates all necessary parent directories if they don't exist.","ref":"Gitly.Utils.FS.html#ensure_dir_exists/1"},{"type":"function","title":"Parameters - Gitly.Utils.FS.ensure_dir_exists/1","doc":"* `path` - The path for which to ensure the directory exists.","ref":"Gitly.Utils.FS.html#ensure_dir_exists/1-parameters"},{"type":"function","title":"Returns - Gitly.Utils.FS.ensure_dir_exists/1","doc":"* `:ok` if successful.\n  * `{:error, reason}` if an error occurs.","ref":"Gitly.Utils.FS.html#ensure_dir_exists/1-returns"},{"type":"function","title":"Examples - Gitly.Utils.FS.ensure_dir_exists/1","doc":"iex> Gitly.Utils.FS.ensure_dir_exists(\"/tmp/new_dir/file.txt\")\n    :ok","ref":"Gitly.Utils.FS.html#ensure_dir_exists/1-examples"},{"type":"function","title":"Gitly.Utils.FS.maybe_move/3","doc":"Conditionally moves a file or directory.","ref":"Gitly.Utils.FS.html#maybe_move/3"},{"type":"function","title":"Parameters - Gitly.Utils.FS.maybe_move/3","doc":"* `source` - The source path.\n  * `dest` - The destination path.\n  * `condition` - Boolean condition determining whether to move.","ref":"Gitly.Utils.FS.html#maybe_move/3-parameters"},{"type":"function","title":"Returns - Gitly.Utils.FS.maybe_move/3","doc":"* `{:ok, dest}` if moved or if condition is false.\n  * `{:error, reason}` if an error occurs during move.","ref":"Gitly.Utils.FS.html#maybe_move/3-returns"},{"type":"function","title":"Examples - Gitly.Utils.FS.maybe_move/3","doc":"iex> Gitly.Utils.FS.maybe_move(\"/tmp/source\", \"/tmp/dest\", true)\n    {:ok, \"/tmp/dest\"}\n\n    iex> Gitly.Utils.FS.maybe_move(\"/tmp/source\", \"/tmp/dest\", false)\n    {:ok, \"/tmp/dest\"}","ref":"Gitly.Utils.FS.html#maybe_move/3-examples"},{"type":"function","title":"Gitly.Utils.FS.maybe_rm_rf/2","doc":"Conditionally removes a directory and all its contents.","ref":"Gitly.Utils.FS.html#maybe_rm_rf/2"},{"type":"function","title":"Parameters - Gitly.Utils.FS.maybe_rm_rf/2","doc":"* `path` - The path to remove.\n  * `condition` - Boolean condition determining whether to remove.","ref":"Gitly.Utils.FS.html#maybe_rm_rf/2-parameters"},{"type":"function","title":"Returns - Gitly.Utils.FS.maybe_rm_rf/2","doc":"* `{:ok, path}` if removed or if condition is false.\n  * `{:error, reason}` if an error occurs during removal.","ref":"Gitly.Utils.FS.html#maybe_rm_rf/2-returns"},{"type":"function","title":"Examples - Gitly.Utils.FS.maybe_rm_rf/2","doc":"iex> Gitly.Utils.FS.maybe_rm_rf(\"/tmp/to_remove\", true)\n    {:ok, \"/tmp/to_remove\"}\n\n    iex> Gitly.Utils.FS.maybe_rm_rf(\"/tmp/to_keep\", false)\n    {:ok, \"/tmp/to_keep\"}","ref":"Gitly.Utils.FS.html#maybe_rm_rf/2-examples"},{"type":"function","title":"Gitly.Utils.FS.move/2","doc":"Moves a file or directory from source to destination.","ref":"Gitly.Utils.FS.html#move/2"},{"type":"function","title":"Parameters - Gitly.Utils.FS.move/2","doc":"* `source` - The source path.\n  * `dest` - The destination path.","ref":"Gitly.Utils.FS.html#move/2-parameters"},{"type":"function","title":"Returns - Gitly.Utils.FS.move/2","doc":"* `{:ok, dest}` if successful.\n  * `{:error, reason}` if an error occurs.","ref":"Gitly.Utils.FS.html#move/2-returns"},{"type":"function","title":"Examples - Gitly.Utils.FS.move/2","doc":"iex> Gitly.Utils.FS.move(\"/tmp/source\", \"/tmp/dest\")\n    {:ok, \"/tmp/dest\"}","ref":"Gitly.Utils.FS.html#move/2-examples"},{"type":"function","title":"Gitly.Utils.FS.rm?/1","doc":"Checks if a path is safe to remove.\n\nPrevents removal of important system directories and non-existent paths.","ref":"Gitly.Utils.FS.html#rm?/1"},{"type":"function","title":"Parameters - Gitly.Utils.FS.rm?/1","doc":"* `dest` - The path to check.","ref":"Gitly.Utils.FS.html#rm?/1-parameters"},{"type":"function","title":"Returns - Gitly.Utils.FS.rm?/1","doc":"* `true` if the path is safe to remove.\n  * `false` otherwise.","ref":"Gitly.Utils.FS.html#rm?/1-returns"},{"type":"function","title":"Examples - Gitly.Utils.FS.rm?/1","doc":"iex> Gitly.Utils.FS.rm?(\"/tmp/safe_to_remove\")\n    true\n\n    iex> Gitly.Utils.FS.rm?(\"/\")\n    false","ref":"Gitly.Utils.FS.html#rm?/1-examples"},{"type":"function","title":"Gitly.Utils.FS.root_path/0","doc":"Returns the root path for Gitly.","ref":"Gitly.Utils.FS.html#root_path/0"},{"type":"function","title":"Returns - Gitly.Utils.FS.root_path/0","doc":"* The path to the Gitly root directory.","ref":"Gitly.Utils.FS.html#root_path/0-returns"},{"type":"function","title":"Examples - Gitly.Utils.FS.root_path/0","doc":"iex> Gitly.Utils.FS.root_path()\n    \"/home/user/.gitly\"","ref":"Gitly.Utils.FS.html#root_path/0-examples"},{"type":"module","title":"Gitly.Utils.Git","doc":"A module to create repository URLs.\n\nThis module provides functionality to generate repository URLs based on\nprovided information such as host, owner, and repository name.","ref":"Gitly.Utils.Git.html"},{"type":"function","title":"Gitly.Utils.Git.create_repo_url/2","doc":"Creates a repository URL.","ref":"Gitly.Utils.Git.html#create_repo_url/2"},{"type":"function","title":"Parameters - Gitly.Utils.Git.create_repo_url/2","doc":"* `repo_info` - A map containing repository information. It must include:\n    * `:host` - The host domain (e.g., \"github.com\")\n    * `:owner` - The repository owner or organization name\n    * `:repo` - The repository name\n  * `suffix` - A boolean indicating whether to append \".git\" to the URL (default: false)","ref":"Gitly.Utils.Git.html#create_repo_url/2-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Git.create_repo_url/2","doc":"* A string containing the constructed repository URL.","ref":"Gitly.Utils.Git.html#create_repo_url/2-returns"},{"type":"function","title":"Examples - Gitly.Utils.Git.create_repo_url/2","doc":"iex> repo_info = %{host: \"github.com\", owner: \"elixir-lang\", repo: \"elixir\"}\n    iex> Gitly.Utils.Git.create_repo_url(repo_info)\n    \"https://github.com/elixir-lang/elixir\"\n\n    iex> repo_info = %{host: \"gitlab.com\", owner: \"gitlab-org\", repo: \"gitlab\"}\n    iex> Gitly.Utils.Git.create_repo_url(repo_info, true)\n    \"https://gitlab.com/gitlab-org/gitlab.git\"","ref":"Gitly.Utils.Git.html#create_repo_url/2-examples"},{"type":"module","title":"Gitly.Utils.Git.Provider","doc":"A module to handle Git provider operations.\n\nThis module provides functionality to identify Git providers and build\narchive URLs for different Git hosting services.","ref":"Gitly.Utils.Git.Provider.html"},{"type":"function","title":"Gitly.Utils.Git.Provider.build_url/3","doc":"Builds the URL for the given provider.","ref":"Gitly.Utils.Git.Provider.html#build_url/3"},{"type":"function","title":"Parameters - Gitly.Utils.Git.Provider.build_url/3","doc":"* `provider` - The host type (`:github`, `:gitlab`, `:bitbucket`, or `:unknown`).\n  * `input` - A map containing repository information. It must include:\n    * `:owner` - The repository owner or organization name.\n    * `:repo` - The repository name.\n    * `:ref` - The reference (branch, tag, or commit).\n  * `format` - The desired archive format (e.g., \"zip\", \"tar.gz\").","ref":"Gitly.Utils.Git.Provider.html#build_url/3-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Git.Provider.build_url/3","doc":"* A string containing the constructed URL for the archive.\n  * `:error` if the provider is unknown.","ref":"Gitly.Utils.Git.Provider.html#build_url/3-returns"},{"type":"function","title":"Examples - Gitly.Utils.Git.Provider.build_url/3","doc":"iex> input = %{owner: \"elixir-lang\", repo: \"elixir\", ref: \"main\"}\n    iex> Gitly.Utils.Git.Provider.build_url(:github, input, \"zip\")\n    \"https://github.com/elixir-lang/elixir/archive/main.zip\"\n\n    iex> input = %{owner: \"gitlab-org\", repo: \"gitlab\", ref: \"master\"}\n    iex> Gitly.Utils.Git.Provider.build_url(:gitlab, input, \"tar.gz\")\n    \"https://gitlab.com/gitlab-org/gitlab/-/archive/master/gitlab-master.tar.gz\"\n\n    iex> input = %{owner: \"atlassian\", repo: \"bitbucket\", ref: \"main\"}\n    iex> Gitly.Utils.Git.Provider.build_url(:bitbucket, input, \"tar.gz\")\n    \"https://bitbucket.org/atlassian/bitbucket/get/main.tar.gz\"\n\n    iex> Gitly.Utils.Git.Provider.build_url(:unknown, %{}, \"zip\")\n    :error","ref":"Gitly.Utils.Git.Provider.html#build_url/3-examples"},{"type":"function","title":"Gitly.Utils.Git.Provider.from_string/1","doc":"Returns the host type based on the given string.","ref":"Gitly.Utils.Git.Provider.html#from_string/1"},{"type":"function","title":"Parameters - Gitly.Utils.Git.Provider.from_string/1","doc":"* `string` - A string containing the host name or URL.","ref":"Gitly.Utils.Git.Provider.html#from_string/1-parameters"},{"type":"function","title":"Returns - Gitly.Utils.Git.Provider.from_string/1","doc":"* The host type as an atom (`:github`, `:gitlab`, `:bitbucket`, or `:unknown`).","ref":"Gitly.Utils.Git.Provider.html#from_string/1-returns"},{"type":"function","title":"Examples - Gitly.Utils.Git.Provider.from_string/1","doc":"iex> Gitly.Utils.Git.Provider.from_string(\"github.com\")\n    :github\n\n    iex> Gitly.Utils.Git.Provider.from_string(\"gitlab\")\n    :gitlab\n\n    iex> Gitly.Utils.Git.Provider.from_string(\"example.com\")\n    :unknown","ref":"Gitly.Utils.Git.Provider.html#from_string/1-examples"},{"type":"type","title":"Gitly.Utils.Git.Provider.host/0","doc":"","ref":"Gitly.Utils.Git.Provider.html#t:host/0"},{"type":"module","title":"Gitly.Utils.Net","doc":"A module to check if the user is online or offline.","ref":"Gitly.Utils.Net.html"},{"type":"function","title":"Gitly.Utils.Net.is_offline?/0","doc":"Checks if the user is offline.","ref":"Gitly.Utils.Net.html#is_offline?/0"},{"type":"function","title":"Gitly.Utils.Net.is_online?/0","doc":"Checks if the user is online.","ref":"Gitly.Utils.Net.html#is_online?/0"},{"type":"behaviour","title":"Gitly.Utils.Net.Behavior","doc":"Defines a behavior for checking network connectivity.\n\nThis behavior specifies functions to determine if the system is online or offline.\nModules implementing this behavior should provide concrete implementations\nfor these functions.","ref":"Gitly.Utils.Net.Behavior.html"},{"type":"callback","title":"Gitly.Utils.Net.Behavior.is_offline?/0","doc":"Checks if the system is offline.\n\nImplementations should return `true` if the system is offline, `false` otherwise.","ref":"Gitly.Utils.Net.Behavior.html#c:is_offline?/0"},{"type":"callback","title":"Gitly.Utils.Net.Behavior.is_online?/0","doc":"Checks if the system is online.\n\nImplementations should return `true` if the system is online, `false` otherwise.","ref":"Gitly.Utils.Net.Behavior.html#c:is_online?/0"},{"type":"module","title":"Gitly.Utils.Net.INet","doc":"A module to check if the user is online or offline.","ref":"Gitly.Utils.Net.INet.html"},{"type":"function","title":"Gitly.Utils.Net.INet.is_offline?/0","doc":"Checks if the user is offline.","ref":"Gitly.Utils.Net.INet.html#is_offline?/0"},{"type":"function","title":"Examples - Gitly.Utils.Net.INet.is_offline?/0","doc":"iex> Gitly.Utils.Net.is_offline?\n    false","ref":"Gitly.Utils.Net.INet.html#is_offline?/0-examples"},{"type":"function","title":"Gitly.Utils.Net.INet.is_online?/0","doc":"Checks if the user is online.","ref":"Gitly.Utils.Net.INet.html#is_online?/0"},{"type":"function","title":"Examples - Gitly.Utils.Net.INet.is_online?/0","doc":"iex> Gitly.Utils.Net.is_online?\n    true","ref":"Gitly.Utils.Net.INet.html#is_online?/0-examples"},{"type":"extras","title":"Gitly","doc":"# Gitly\n\nAn Elixir library for easily downloading and extracting Git repositories from various hosting services.\n\n[![codecov](https://codecov.io/gh/iwatakeshi/gitly_ex/graph/badge.svg?token=5XYXSI97PO)](https://codecov.io/gh/iwatakeshi/gitly_ex)\n[![Elixir CI](https://github.com/iwatakeshi/gitly_ex/actions/workflows/elixir.yml/badge.svg)](https://github.com/iwatakeshi/gitly_ex/actions/workflows/elixir.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/gitly.svg)](https://hex.pm/packages/gitly)\n[![Hex.pm](https://img.shields.io/hexpm/dt/gitly.svg)](https://hex.pm/packages/gitly)\n[![Hex.pm](https://img.shields.io/hexpm/l/gitly.svg)](https://hex.pm/packages/gitly)","ref":"readme.html"},{"type":"extras","title":"Features - Gitly","doc":"- Download repositories from popular Git hosts\n- Extract downloaded archives\n- Flexible options for caching, retrying, and formatting\n- Support for various archive formats (zip, tar, tar.gz, tgz) if supported by the provider\n- Support for various hosts (GitHub, GitLab, BitBucket)","ref":"readme.html#features"},{"type":"extras","title":"Installation - Gitly","doc":"Add `gitly` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:gitly, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen run `mix deps.get` to install the dependency.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Gitly","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Basic Usage - Gitly","doc":"To download and extract a repository:\n\n```elixir\nimport Gitly, only: [gitly: 1, gitly: 2]\n{:ok, path} = gitly(\"username/repo\")\n```\n\nThis will download the repository and return the path to the extracted contents.\n\nThe following inputs are supported:\n\n- `owner/repo`\n- `https://host.com/owner/repo`\n- `https://host.com/owner/repo.git`\n- `host.com/owner/repo`\n- `host:owner/repo`\n\n#### Note\n\n`gitly` will return the path that includes the root of the extracted directory.\nIf there are more than one folder in the parent directory, then the path to the parent directory would be returned.\nThis behavior may change in the future.","ref":"readme.html#basic-usage"},{"type":"extras","title":"Download Only - Gitly","doc":"If you only want to download the repository without extracting:\n\n```elixir\nimport Gitly, only: [download: 1, download: 2]\n{:ok, _path} = download(\"username/repo\")\n```","ref":"readme.html#download-only"},{"type":"extras","title":"Extract an Existing Archive - Gitly","doc":"To extract an already downloaded archive:\n\n```elixir\nimport Gitly, only: [extract: 1, extract: 2]\n{:ok, _path } = extract(\"/path/to/archive.zip\")\n```\n\nOr to specify a destination:\n\n```elixir\nimport Gitly, only: [extract: 1, extract: 2]\n{:ok, _path } = extract(\"/path/to/archive.zip\", \"/path/to/destination\")\n```\n\n#### Note\n\n`extract` will return the path that you specified.","ref":"readme.html#extract-an-existing-archive"},{"type":"extras","title":"Options - Gitly","doc":"Gitly supports various options to customize its behavior:\n\n- `:force` - Force download even if the archive already exists\n- `:cache` - Use local cache for downloads\n- `:overwrite` - Overwrite existing files when extracting\n- `:retry` - Retry options for failed downloads\n- `:retry_delay` - Custom function to determine delay between retries\n- `:retry_log_level` - Set log level for retry attempts\n- `:max_retries` - Maximum number of retry attempts\n- `:ref` - Specify a particular Git reference to download\n- `:root` - Set the root path for storing archives\n- `:format` - Specify the archive format (:zip, :tar, :tar_gz, or :tgz)\n\nExample with options:\n\n```elixir\nimport Gitly, only: [gitly: 1, gitly: 2]\ngitly(\"username/repo\", force: true, format: :zip, ref: \"main\")\n```","ref":"readme.html#options"},{"type":"extras","title":"Documentation - Gitly","doc":"For more detailed documentation, run `mix docs` and open `doc/index.html` in your browser.\n\nThis project uses [git-cliff](https://github.com/orhun/git-cliff) for changelog generation.","ref":"readme.html#documentation"},{"type":"extras","title":"Contributing - Gitly","doc":"Contributions are welcome! Please feel free to submit a Pull Request.","ref":"readme.html#contributing"},{"type":"extras","title":"License - Gitly","doc":"This project is licensed under the [MIT License](LICENSE).","ref":"readme.html#license"},{"type":"extras","title":"Changelog - Gitly","doc":"See [CHANGELOG.md](CHANGELOG.md) for the latest changes.","ref":"readme.html#changelog"},{"type":"extras","title":"LICENSE","doc":"Copyright (c) 2024 Takeshi Iwana\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]","ref":"changelog.html"},{"type":"extras","title":"Changed - Changelog","doc":"- Add tests\n\n\n<!-- generated by git-cliff -->","ref":"changelog.html#changed"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}